@@ -77,12 +77,15 @@ class Inspector(object):
         if tables:
             tasks = []
             pool = ThreadPool(processes=len(tables))
-            for table in tables:
-                tasks.append(pool.apply_async(self.__inspect_table, (table,)))
-            for task in tasks:
-                table_warnings, table_report = task.get()
-                warnings.extend(table_warnings)
-                table_reports.append(table_report)
+            try:
+                for table in tables:
+                    tasks.append(pool.apply_async(self.__inspect_table, (table,)))
+                for task in tasks:
+                    table_warnings, table_report = task.get()
+                    warnings.extend(table_warnings)
+                    table_reports.append(table_report)
+            finally:
+                pool.terminate()
 
         # Stop timer
         stop = datetime.datetime.now()
@@ -258,7 +261,7 @@ class Inspector(object):
         stop = datetime.datetime.now()
 
         # Compose report
-        headers = headers if None not in headers else None
+        headers = headers if any(elt is not None for elt in headers) else None
         if self.__error_limit != float('inf'):
             errors = errors[:self.__error_limit]
         errors = sorted(errors)
